<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/compresseur?lang_cible=br
// ** ne pas modifier le fichier **

return [

	// E
	'explication_url_statique_ressources' => 'Un URL evit kas fichennoù stadegouriezh (skeudennoù, JS...) hep cookie. Peurliesañ un iz-domani all o bukañ ivez war al lec’hienn.',

	// I
	'info_compresseur_titre' => 'Gwellekaat ha gwaskañ',
	'info_question_activer_compactage_css' => 'CSS',
	'info_question_activer_compactage_js' => 'Skriptoù',
	'item_compresseur_css' => 'Gweredekaat gwaskadur ar follennoù stil (CSS)',
	'item_compresseur_js' => 'Gweredekaat gwaskadur ar skriptoù (javascript)',

	// L
	'label_url_statique_ressources' => 'URL danvezioù',

	// T
	'texte_compacter_avertissement' => 'Diwallit da chom hep gweredekaat an dibarzhioù-mañ e-keit hag emeur o sevel ho lec’hienn : n’hall ket an elfennoù stummaet bezañ lennet ken war-lerc’h.',
	'texte_compacter_script_css' => 'Gallout a ra SPIP stummaat ar skriptoù javascript hag ar follennoù-stil CSS, evit enrollañ anezho er restroù statek ;  buanoc’h e teu al lec’hienn war wel.',
	'titre_compacter_script_css' => 'Stummaat ar skriptoù ha CSS',
];
